==> jc-1.4.0.tar.gz: java/lang/IllegalThreadStateException.h <==
// public class java.lang.IllegalThreadStateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 4cb670dd3abbf976 java_lang_IllegalThreadStateException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_lang_IllegalThreadStateException_H_
#define _JC_java_lang_IllegalThreadStateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_IllegalThreadStateException$sub_refs	_jc_java_lang_IllegalThreadStateException$sub_refs;
typedef struct _jc_java_lang_IllegalThreadStateException$sub_nonrefs	_jc_java_lang_IllegalThreadStateException$sub_nonrefs;
typedef struct _jc_java_lang_IllegalThreadStateException$refs	_jc_java_lang_IllegalThreadStateException$refs;
typedef struct _jc_java_lang_IllegalThreadStateException$nonrefs	_jc_java_lang_IllegalThreadStateException$nonrefs;
typedef struct _jc_java_lang_IllegalThreadStateException$object	_jc_java_lang_IllegalThreadStateException$object;

typedef struct _jc_java_lang_IllegalThreadStateException$fields_struct	_jc_java_lang_IllegalThreadStateException$fields_struct;
typedef const struct _jc_java_lang_IllegalThreadStateException$vmethods	_jc_java_lang_IllegalThreadStateException$vmethods;
typedef const struct _jc_java_lang_IllegalThreadStateException$vtable	_jc_java_lang_IllegalThreadStateException$vtable;
typedef const struct _jc_java_lang_IllegalThreadStateException$vtype	_jc_java_lang_IllegalThreadStateException$vtype;

// Class fields structure
struct _jc_java_lang_IllegalThreadStateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_IllegalThreadStateException$fields_struct _jc_java_lang_IllegalThreadStateException$class_fields;

// Constructors
extern void _jc_java_lang_IllegalThreadStateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_IllegalThreadStateException$object *);
extern void _jc_java_lang_IllegalThreadStateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_IllegalThreadStateException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_IllegalThreadStateException$vmethods {
};

// Vtable
struct _jc_java_lang_IllegalThreadStateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_lang_IllegalThreadStateException$vmethods	java_lang_IllegalThreadStateException;
};

// Vtype
struct _jc_java_lang_IllegalThreadStateException$vtype {
	_jc_type			type;
	_jc_java_lang_IllegalThreadStateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_IllegalThreadStateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_IllegalThreadStateException$refs {
    _jc_java_lang_IllegalThreadStateException$sub_refs	java_lang_IllegalThreadStateException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_IllegalThreadStateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_IllegalThreadStateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_lang_IllegalThreadStateException$sub_nonrefs	java_lang_IllegalThreadStateException;
};

// Object instance structure
struct _jc_java_lang_IllegalThreadStateException$object {
	_jc_java_lang_IllegalThreadStateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_IllegalThreadStateException$vtype	*vtype;
	_jc_java_lang_IllegalThreadStateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_IllegalThreadStateException$vtype _jc_java_lang_IllegalThreadStateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_IllegalThreadStateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_IllegalThreadStateException$class_object;

#endif	/* _JC_java_lang_IllegalThreadStateException_H_ */

==> jc-1.4.6.tar.gz: java/lang/IllegalThreadStateException.h <==
// public class java.lang.IllegalThreadStateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 4cb670dd3abbf976 java_lang_IllegalThreadStateException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_lang_IllegalThreadStateException_H_
#define _JC_java_lang_IllegalThreadStateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_IllegalThreadStateException$sub_refs	_jc_java_lang_IllegalThreadStateException$sub_refs;
typedef struct _jc_java_lang_IllegalThreadStateException$sub_nonrefs	_jc_java_lang_IllegalThreadStateException$sub_nonrefs;
typedef struct _jc_java_lang_IllegalThreadStateException$refs	_jc_java_lang_IllegalThreadStateException$refs;
typedef struct _jc_java_lang_IllegalThreadStateException$nonrefs	_jc_java_lang_IllegalThreadStateException$nonrefs;
typedef struct _jc_java_lang_IllegalThreadStateException$object	_jc_java_lang_IllegalThreadStateException$object;

typedef struct _jc_java_lang_IllegalThreadStateException$fields_struct	_jc_java_lang_IllegalThreadStateException$fields_struct;
typedef const struct _jc_java_lang_IllegalThreadStateException$vmethods	_jc_java_lang_IllegalThreadStateException$vmethods;
typedef const struct _jc_java_lang_IllegalThreadStateException$vtable	_jc_java_lang_IllegalThreadStateException$vtable;
typedef const struct _jc_java_lang_IllegalThreadStateException$vtype	_jc_java_lang_IllegalThreadStateException$vtype;

// Class fields structure
struct _jc_java_lang_IllegalThreadStateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_IllegalThreadStateException$fields_struct _jc_java_lang_IllegalThreadStateException$class_fields;

// Constructors
extern void _jc_java_lang_IllegalThreadStateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_IllegalThreadStateException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_IllegalThreadStateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_IllegalThreadStateException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_IllegalThreadStateException$vmethods {
};

// Vtable
struct _jc_java_lang_IllegalThreadStateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_lang_IllegalThreadStateException$vmethods	java_lang_IllegalThreadStateException;
};

// Vtype
struct _jc_java_lang_IllegalThreadStateException$vtype {
	_jc_type			type;
	_jc_java_lang_IllegalThreadStateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_IllegalThreadStateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_IllegalThreadStateException$refs {
    _jc_java_lang_IllegalThreadStateException$sub_refs	java_lang_IllegalThreadStateException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_IllegalThreadStateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_IllegalThreadStateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_lang_IllegalThreadStateException$sub_nonrefs	java_lang_IllegalThreadStateException;
};

// Object instance structure
struct _jc_java_lang_IllegalThreadStateException$object {
	_jc_java_lang_IllegalThreadStateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_IllegalThreadStateException$vtype	*vtype;
	_jc_java_lang_IllegalThreadStateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_IllegalThreadStateException$vtype _jc_java_lang_IllegalThreadStateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_IllegalThreadStateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_IllegalThreadStateException$class_object;

#endif	/* _JC_java_lang_IllegalThreadStateException_H_ */
